import 'dart:async';
import 'package:flutter/services.dart';

enum TheoremReachListener {
  onReward,
  theoremReachSurveyAvailable,
  onRewardCenterOpened,
  onRewardCenterClosed
}

typedef TheoremListener(TheoremReachListener listener);

class TheoremReach {
  static const MethodChannel _channel = const MethodChannel('theoremreach');

  static final MethodChannel channel = MethodChannel('theoremreach');
  static final Map<String, TheoremReachListener> theoremReachListener = {
    'onRewardCenterClosed': TheoremReachListener.onRewardCenterClosed,
    'onRewardCenterOpened': TheoremReachListener.onRewardCenterOpened,
    'theoremReachSurveyAvailable':
        TheoremReachListener.theoremReachSurveyAvailable,
    'onReward': TheoremReachListener.onReward,
  };

  Future<void> init(
      {String apiToken, String userId, TheoremListener listener}) async {
    channel.setMethodCallHandler(
        (MethodCall call) async => handleMethod(call, listener));
    assert(apiToken != null && apiToken.isNotEmpty);
    return _channel.invokeMethod(
        "init", <String, dynamic>{"api_token": apiToken, "user_id": userId});
  }

  Future<void> show() {
    return _channel.invokeMethod("show");
  }

  Future<void> setNavBarText({String text}) {
    return _channel
        .invokeMethod('setNavBarText', <String, dynamic>{'text': text});
  }

  Future<void> setNavBarColor({String color}) {
    return _channel
        .invokeMethod('setNavBarColor', <String, dynamic>{'color': color});
  }

  Future<void> setNavBarTextColor({String textColor}) {
    return _channel.invokeMethod(
        'setNavBarTextColor', <String, dynamic>{'text_color': textColor});
  }

  static Future<void> handleMethod(
      MethodCall call, TheoremListener listener) async {
    listener(theoremReachListener[call.method]);
  }
}
